@@ -317,34 +317,6 @@ while (time < $s) {
     );
 } ## end while (time < $s)
 
-print_it($F, 'Horizontal Gradient Filled Pie Test');
-$s = time + $factor;
-while (time < $s) {
-    $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->filled_pie(
-        {
-            'x'             => rand($XX),
-            'y'             => rand($YY),
-            'radius'        => rand($center_y),
-            'start_degrees' => rand(360),
-            'end_degrees'   => rand(360),
-            'gradient'      => {
-                'direction' => 'horizontal',
-                'start' => {
-                    'red'   => rand(256),
-                    'green' => rand(256),
-                    'blue'  => rand(256)
-                },
-                'end' => {
-                    'red'   => rand(256),
-                    'green' => rand(256),
-                    'blue'  => rand(256)
-                }
-            }
-        }
-    );
-} ## end while (time < $s)
-
 print_it($F, 'Ellipse Test');
 $s = time + $factor;
 while (time < $s) {
@@ -452,31 +424,6 @@ while (time < $s) {
     );
 } ## end while (time < $s)
 
-print_it($F, 'Horizontal Gradient Polygon Test');
-$s = time + $factor;
-while (time < $s) {
-    $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->polygon(
-        {
-            'coordinates' => [rand($XX), rand($YY), rand($XX), rand($YY), rand($XX), rand($YY), rand($XX), rand($YY)],
-            'filled'      => 1,
-            'gradient'    => {
-                'direction' => 'horizontal',
-                'start' => {
-                    'red'   => rand(256),
-                    'green' => rand(256),
-                    'blue'  => rand(256)
-                },
-                'end' => {
-                    'red'   => rand(256),
-                    'green' => rand(256),
-                    'blue'  => rand(256)
-                }
-            }
-        }
-    );
-} ## end while (time < $s)
-
 print_it($F, 'Testing Bezier Curves');
 
 $s = time + $factor;
