@@ -64,10 +64,10 @@ foreach my $F (@f) {
             my $FB = shift;
             my $p  = shift;
             system('clear');
-            $FB->cls();
+            $FB->cls('OFF');
 
             show($FB,$p);
-            $FB->cls();
+            $FB->cls('ON');
         },
         $F,
         scalar(@pics)
